# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_INT = object
IntCtrl = object
IntUpdatedEvent = object
IntValidator = object
LONGTYPE = object
MAXSIZE = 0
MINSIZE = 0
WXK_CTRL_V = 0
WXK_CTRL_X = 0
wxEVT_COMMAND_INT_UPDATED = 0
