# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BuildLanguageCountryMapping = dummy_function
CreateLanguagesResourceLists = dummy_function
GetLanguageFlag = dummy_function
GetWxIdentifierForLanguage = dummy_function
LC_ALL = 0
LC_AVAILABLE = 0
LC_ONLY = 0
LanguageListCtrl = object
_l = ''
_wxLangIds = []
langIdCountryMap = dict()
