# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AbortEvent = object
AbortedException = object
DelayedResult = object
Handler = object
PreProcessChain = object
Producer = object
Sender = object
SenderCallAfter = object
SenderNoWx = object
SenderWxEvent = object
Struct = object
startWorker = dummy_function
