# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DATAVIEW_CELL_ACTIVATABLE = object
DATAVIEW_CELL_EDITABLE = object
DATAVIEW_CELL_FOCUSED = object
DATAVIEW_CELL_INERT = object
DATAVIEW_CELL_INSENSITIVE = object
DATAVIEW_CELL_PRELIT = object
DATAVIEW_CELL_SELECTED = object
DATAVIEW_COL_HIDDEN = object
DATAVIEW_COL_REORDERABLE = object
DATAVIEW_COL_RESIZABLE = object
DATAVIEW_COL_SORTABLE = object
DVC_DEFAULT_MINWIDTH = 0
DVC_DEFAULT_RENDERER_SIZE = 0
DVC_DEFAULT_WIDTH = 0
DVC_TOGGLE_DEFAULT_WIDTH = 0
DVR_DEFAULT_ALIGNMENT = 0
DV_HORIZ_RULES = 0
DV_MULTIPLE = 0
DV_NO_HEADER = 0
DV_ROW_LINES = 0
DV_SINGLE = 0
DV_VARIABLE_LINE_HEIGHT = 0
DV_VERT_RULES = 0
DataViewBitmapRenderer = object
DataViewCellMode = object
DataViewCellRenderState = object
DataViewChoiceRenderer = object
DataViewColumn = object
DataViewColumnFlags = object
DataViewCtrl = object
DataViewCtrlNameStr = bytes()
DataViewCustomRenderer = object
DataViewDateRenderer = object
DataViewEvent = object
DataViewIconText = object
DataViewIconTextRenderer = object
DataViewIndexListModel = object
DataViewItem = object
DataViewItemArray = object
DataViewItemAttr = object
DataViewItemObjectMapper = object
DataViewListCtrl = object
DataViewListModel = object
DataViewListStore = object
DataViewModel = object
DataViewModelNotifier = object
DataViewProgressRenderer = object
DataViewRenderer = object
DataViewSpinRenderer = object
DataViewTextRenderer = object
DataViewToggleRenderer = object
DataViewTreeCtrl = object
DataViewTreeStore = object
DataViewVirtualListModel = object
EVT_DATAVIEW_CACHE_HINT = object
EVT_DATAVIEW_COLUMN_HEADER_CLICK = object
EVT_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = object
EVT_DATAVIEW_COLUMN_REORDERED = object
EVT_DATAVIEW_COLUMN_SORTED = object
EVT_DATAVIEW_ITEM_ACTIVATED = object
EVT_DATAVIEW_ITEM_BEGIN_DRAG = object
EVT_DATAVIEW_ITEM_COLLAPSED = object
EVT_DATAVIEW_ITEM_COLLAPSING = object
EVT_DATAVIEW_ITEM_CONTEXT_MENU = object
EVT_DATAVIEW_ITEM_DROP = object
EVT_DATAVIEW_ITEM_DROP_POSSIBLE = object
EVT_DATAVIEW_ITEM_EDITING_DONE = object
EVT_DATAVIEW_ITEM_EDITING_STARTED = object
EVT_DATAVIEW_ITEM_EXPANDED = object
EVT_DATAVIEW_ITEM_EXPANDING = object
EVT_DATAVIEW_ITEM_START_EDITING = object
EVT_DATAVIEW_ITEM_VALUE_CHANGED = object
EVT_DATAVIEW_SELECTION_CHANGED = object
EVT_TREELIST_COLUMN_SORTED = object
EVT_TREELIST_ITEM_ACTIVATED = object
EVT_TREELIST_ITEM_CHECKED = object
EVT_TREELIST_ITEM_CONTEXT_MENU = object
EVT_TREELIST_ITEM_EXPANDED = object
EVT_TREELIST_ITEM_EXPANDING = object
EVT_TREELIST_SELECTION_CHANGED = object
NullDataViewItem = object
PyDataViewCustomRenderer = object
PyDataViewIndexListModel = object
PyDataViewModel = object
PyDataViewVirtualListModel = object
TLI_FIRST = object
TLI_LAST = object
TL_3STATE = 0
TL_CHECKBOX = 0
TL_DEFAULT_STYLE = 0
TL_MULTIPLE = 0
TL_NO_HEADER = 0
TL_SINGLE = 0
TL_STYLE_MASK = 0
TL_USER_3STATE = 0
TreeListCtrl = object
TreeListCtrlNameStr = bytes()
TreeListEvent = object
TreeListItem = object
TreeListItemComparator = object
wxEVT_COMMAND_DATAVIEW_CACHE_HINT = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_HEADER_CLICK = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_REORDERED = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_SORTED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_ACTIVATED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_BEGIN_DRAG = 0
wxEVT_COMMAND_DATAVIEW_ITEM_COLLAPSED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_COLLAPSING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_CONTEXT_MENU = 0
wxEVT_COMMAND_DATAVIEW_ITEM_DROP = 0
wxEVT_COMMAND_DATAVIEW_ITEM_DROP_POSSIBLE = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EDITING_DONE = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EDITING_STARTED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EXPANDED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EXPANDING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_START_EDITING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_VALUE_CHANGED = 0
wxEVT_COMMAND_DATAVIEW_SELECTION_CHANGED = 0
wxEVT_COMMAND_TREELIST_COLUMN_SORTED = 0
wxEVT_COMMAND_TREELIST_ITEM_ACTIVATED = 0
wxEVT_COMMAND_TREELIST_ITEM_CHECKED = 0
wxEVT_COMMAND_TREELIST_ITEM_CONTEXT_MENU = 0
wxEVT_COMMAND_TREELIST_ITEM_EXPANDED = 0
wxEVT_COMMAND_TREELIST_ITEM_EXPANDING = 0
wxEVT_COMMAND_TREELIST_SELECTION_CHANGED = 0
wxEVT_DATAVIEW_CACHE_HINT = 0
wxEVT_DATAVIEW_COLUMN_HEADER_CLICK = 0
wxEVT_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = 0
wxEVT_DATAVIEW_COLUMN_REORDERED = 0
wxEVT_DATAVIEW_COLUMN_SORTED = 0
wxEVT_DATAVIEW_ITEM_ACTIVATED = 0
wxEVT_DATAVIEW_ITEM_BEGIN_DRAG = 0
wxEVT_DATAVIEW_ITEM_COLLAPSED = 0
wxEVT_DATAVIEW_ITEM_COLLAPSING = 0
wxEVT_DATAVIEW_ITEM_CONTEXT_MENU = 0
wxEVT_DATAVIEW_ITEM_DROP = 0
wxEVT_DATAVIEW_ITEM_DROP_POSSIBLE = 0
wxEVT_DATAVIEW_ITEM_EDITING_DONE = 0
wxEVT_DATAVIEW_ITEM_EDITING_STARTED = 0
wxEVT_DATAVIEW_ITEM_EXPANDED = 0
wxEVT_DATAVIEW_ITEM_EXPANDING = 0
wxEVT_DATAVIEW_ITEM_START_EDITING = 0
wxEVT_DATAVIEW_ITEM_VALUE_CHANGED = 0
wxEVT_DATAVIEW_SELECTION_CHANGED = 0
wxEVT_TREELIST_COLUMN_SORTED = 0
wxEVT_TREELIST_ITEM_ACTIVATED = 0
wxEVT_TREELIST_ITEM_CHECKED = 0
wxEVT_TREELIST_ITEM_CONTEXT_MENU = 0
wxEVT_TREELIST_ITEM_EXPANDED = 0
wxEVT_TREELIST_ITEM_EXPANDING = 0
wxEVT_TREELIST_SELECTION_CHANGED = 0
