# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CheckListCtrlMixin = object
EventChooser = object
EventLog = object
EventWatcher = object
OTHER_WIDTH = 0
_buildModuleEventMap = dummy_function
_eventBinders = None
_eventIdMap = None
_makeAttribString = dummy_function
_makeSourceString = dummy_function
_noWatchList = []
addModuleEvents = dummy_function
buildWxEventMap = dummy_function
cmp = dummy_function
