# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


grayOut = dummy_function
makeGray = dummy_function
stepColour = dummy_function
