# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


ColDragWindow = object
EVT_GRID_COL_MOVE = object
EVT_GRID_ROW_MOVE = object
GridColMoveEvent = object
GridColMover = object
GridRowMoveEvent = object
GridRowMover = object
RowDragWindow = object
_ColToRect = dummy_function
_RowToRect = dummy_function
wxEVT_COMMAND_GRID_COL_MOVE = 0
wxEVT_COMMAND_GRID_ROW_MOVE = 0
