# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


ColourSelect = object
ColourSelectEvent = object
CustomColourData = object
EVT_COLOURSELECT = object
wxEVT_COMMAND_COLOURSELECT = 0
