# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Animation = object
EmptyXmlResource = dummy_function
ID_NONE = object
XRCCTRL = dummy_function
XRCID = dummy_function
XRC_NO_RELOADING = object
XRC_NO_SUBCLASSING = object
XRC_USE_LOCALE = object
XmlResource = object
XmlResourceFlags = object
XmlResourceHandler = object
XmlSubclassFactory = object
XmlSubclassFactory_Python = object
_my_import = dummy_function
