# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


MultiMessageBox = dummy_function
SOT = 0
SoftwareUpdate = object
URLError = object
UpdateAbortedError = object
urlopen = dummy_function
