# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_HTML_CELL_CLICKED = object
EVT_HTML_CELL_HOVER = object
EVT_HTML_LINK_CLICKED = object
HF_BOOKMARKS = 0
HF_CONTENTS = 0
HF_DEFAULT_STYLE = 0
HF_DIALOG = 0
HF_EMBEDDED = 0
HF_FLAT_TOOLBAR = 0
HF_FRAME = 0
HF_ICONS_BOOK = 0
HF_ICONS_BOOK_CHAPTER = 0
HF_ICONS_FOLDER = 0
HF_INDEX = 0
HF_MERGE_BOOKS = 0
HF_MODAL = 0
HF_OPEN_FILES = 0
HF_PRINT = 0
HF_SEARCH = 0
HF_TOOLBAR = 0
HLB_DEFAULT_STYLE = 0
HLB_MULTIPLE = 0
HTML_ALIGN_BOTTOM = 0
HTML_ALIGN_CENTER = 0
HTML_ALIGN_JUSTIFY = 0
HTML_ALIGN_LEFT = 0
HTML_ALIGN_RIGHT = 0
HTML_ALIGN_TOP = 0
HTML_BLOCK = object
HTML_CLR_BACKGROUND = 0
HTML_CLR_FOREGROUND = 0
HTML_CLR_TRANSPARENT_BACKGROUND = 0
HTML_COND_ISANCHOR = 0
HTML_COND_ISIMAGEMAP = 0
HTML_COND_USER = 0
HTML_FIND_EXACT = 0
HTML_FIND_NEAREST_AFTER = 0
HTML_FIND_NEAREST_BEFORE = 0
HTML_INDENT_ALL = 0
HTML_INDENT_BOTTOM = 0
HTML_INDENT_HORIZONTAL = 0
HTML_INDENT_LEFT = 0
HTML_INDENT_RIGHT = 0
HTML_INDENT_TOP = 0
HTML_INDENT_VERTICAL = 0
HTML_OPEN = object
HTML_REDIRECT = object
HTML_SCRIPT_NORMAL = object
HTML_SCRIPT_SUB = object
HTML_SCRIPT_SUP = object
HTML_SEL_CHANGING = object
HTML_SEL_IN = object
HTML_SEL_OUT = object
HTML_UNITS_PERCENT = 0
HTML_UNITS_PIXELS = 0
HTML_URL_IMAGE = object
HTML_URL_OTHER = object
HTML_URL_PAGE = object
HW_DEFAULT_STYLE = 0
HW_NO_SELECTION = 0
HW_SCROLLBAR_AUTO = 0
HW_SCROLLBAR_NEVER = 0
HtmlBookRecArray = object
HtmlBookRecord = object
HtmlCell = object
HtmlCellEvent = object
HtmlColourCell = object
HtmlContainerCell = object
HtmlDCRenderer = object
HtmlEasyPrinting = object
HtmlFilter = object
HtmlFontCell = object
HtmlHelpController = object
HtmlHelpData = object
HtmlHelpDataItem = object
HtmlHelpDataItems = object
HtmlHelpDialog = object
HtmlHelpFrame = object
HtmlHelpWindow = object
HtmlLinkEvent = object
HtmlLinkInfo = object
HtmlListBox = object
HtmlListBoxNameStr = bytes()
HtmlModalHelp = object
HtmlOpeningStatus = object
HtmlParser = object
HtmlPrintout = object
HtmlRenderingInfo = object
HtmlRenderingState = object
HtmlRenderingStyle = object
HtmlScriptMode = object
HtmlSelection = object
HtmlSelectionState = object
HtmlTag = object
HtmlTagHandler = object
HtmlURLType = object
HtmlWidgetCell = object
HtmlWinParser = object
HtmlWinParser_AddTagHandler = dummy_function
HtmlWinTagHandler = object
HtmlWindow = object
HtmlWindowInterface = object
HtmlWordCell = object
HtmlWordWithTabsCell = object
ID_HTML_BACK = 0
ID_HTML_BOOKMARKSADD = 0
ID_HTML_BOOKMARKSLIST = 0
ID_HTML_BOOKMARKSREMOVE = 0
ID_HTML_COUNTINFO = 0
ID_HTML_DOWN = 0
ID_HTML_FORWARD = 0
ID_HTML_HELPFRAME = 0
ID_HTML_INDEXBUTTON = 0
ID_HTML_INDEXBUTTONALL = 0
ID_HTML_INDEXLIST = 0
ID_HTML_INDEXPAGE = 0
ID_HTML_INDEXTEXT = 0
ID_HTML_NOTEBOOK = 0
ID_HTML_OPENFILE = 0
ID_HTML_OPTIONS = 0
ID_HTML_PANEL = 0
ID_HTML_PRINT = 0
ID_HTML_SEARCHBUTTON = 0
ID_HTML_SEARCHCHOICE = 0
ID_HTML_SEARCHLIST = 0
ID_HTML_SEARCHPAGE = 0
ID_HTML_SEARCHTEXT = 0
ID_HTML_TREECTRL = 0
ID_HTML_UP = 0
ID_HTML_UPNODE = 0
INT_MAX = 0
PAGE_ALL = 0
PAGE_EVEN = 0
PAGE_ODD = 0
SimpleHtmlListBox = object
SimpleHtmlListBoxNameStr = bytes()
wxEVT_COMMAND_HTML_CELL_CLICKED = 0
wxEVT_COMMAND_HTML_CELL_HOVER = 0
wxEVT_COMMAND_HTML_LINK_CLICKED = 0
wxEVT_HTML_CELL_CLICKED = 0
wxEVT_HTML_CELL_HOVER = 0
wxEVT_HTML_LINK_CLICKED = 0
