# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


XMLDOC_KEEP_WHITESPACE_NODES = object
XMLDOC_NONE = object
XML_ATTRIBUTE_NODE = object
XML_CDATA_SECTION_NODE = object
XML_COMMENT_NODE = object
XML_DOCUMENT_FRAG_NODE = object
XML_DOCUMENT_NODE = object
XML_DOCUMENT_TYPE_NODE = object
XML_ELEMENT_NODE = object
XML_ENTITY_NODE = object
XML_ENTITY_REF_NODE = object
XML_HTML_DOCUMENT_NODE = object
XML_NOTATION_NODE = object
XML_NO_INDENTATION = 0
XML_PI_NODE = object
XML_TEXT_NODE = object
XmlAttribute = object
XmlDocument = object
XmlDocumentLoadFlag = object
XmlNode = object
XmlNodeType = object
XmlProperty = object
