# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AbrWeekday = dict()
BusCalDays = []
COLOR_3D_DARK = ''
COLOR_3D_LIGHT = ''
COLOR_BACKGROUND = ''
COLOR_BORDER = ''
COLOR_FONT = ''
COLOR_GRID_LINES = ''
COLOR_HEADER_BACKGROUND = ''
COLOR_HEADER_FONT = ''
COLOR_HIGHLIGHT_BACKGROUND = ''
COLOR_HIGHLIGHT_FONT = ''
COLOR_SELECTION_BACKGROUND = ''
COLOR_SELECTION_FONT = ''
COLOR_WEEKEND_BACKGROUND = ''
COLOR_WEEKEND_FONT = ''
CalDays = []
CalDraw = object
CalenDlg = object
Calendar = object
DefaultColors = dummy_function
EVT_CALENDAR = object
GetMonthList = dummy_function
MakeColor = dummy_function
Month = dict()
PrtCalDraw = object
_ = dummy_function
_MIDSIZE = 0
wxEVT_COMMAND_PYCALENDAR_DAY_CLICKED = 0
