# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RIBBONBAR_HELP_CLICK = object
EVT_RIBBONBAR_PAGE_CHANGED = object
EVT_RIBBONBAR_PAGE_CHANGING = object
EVT_RIBBONBAR_TAB_LEFT_DCLICK = object
EVT_RIBBONBAR_TAB_MIDDLE_DOWN = object
EVT_RIBBONBAR_TAB_MIDDLE_UP = object
EVT_RIBBONBAR_TAB_RIGHT_DOWN = object
EVT_RIBBONBAR_TAB_RIGHT_UP = object
EVT_RIBBONBAR_TOGGLED = object
EVT_RIBBONBUTTONBAR_CLICKED = object
EVT_RIBBONBUTTONBAR_DROPDOWN_CLICKED = object
EVT_RIBBONGALLERY_CLICKED = object
EVT_RIBBONGALLERY_HOVER_CHANGED = object
EVT_RIBBONGALLERY_SELECTED = object
EVT_RIBBONPANEL_EXTBUTTON_ACTIVATED = object
EVT_RIBBONTOOLBAR_CLICKED = object
EVT_RIBBONTOOLBAR_DROPDOWN_CLICKED = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BORDER_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BORDER_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_DISABLED_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_FONT = object
RIBBON_ART_GALLERY_BITMAP_PADDING_BOTTOM_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_LEFT_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_RIGHT_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_TOP_SIZE = object
RIBBON_ART_GALLERY_BORDER_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_FACE_COLOUR = object
RIBBON_ART_GALLERY_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_ITEM_BORDER_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_BORDER_BOTTOM_SIZE = object
RIBBON_ART_PAGE_BORDER_COLOUR = object
RIBBON_ART_PAGE_BORDER_LEFT_SIZE = object
RIBBON_ART_PAGE_BORDER_RIGHT_SIZE = object
RIBBON_ART_PAGE_BORDER_TOP_SIZE = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_BORDER_COLOUR = object
RIBBON_ART_PANEL_BORDER_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_COLOUR = object
RIBBON_ART_PANEL_LABEL_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_LABEL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_LABEL_COLOUR = object
RIBBON_ART_PANEL_LABEL_FONT = object
RIBBON_ART_PANEL_MINIMISED_BORDER_COLOUR = object
RIBBON_ART_PANEL_MINIMISED_BORDER_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_MINIMISED_LABEL_COLOUR = object
RIBBON_ART_PANEL_X_SEPARATION_SIZE = object
RIBBON_ART_PANEL_Y_SEPARATION_SIZE = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TAB_BORDER_COLOUR = object
RIBBON_ART_TAB_CTRL_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_CTRL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TAB_LABEL_COLOUR = object
RIBBON_ART_TAB_LABEL_FONT = object
RIBBON_ART_TAB_SEPARATION_SIZE = object
RIBBON_ART_TAB_SEPARATOR_COLOUR = object
RIBBON_ART_TAB_SEPARATOR_GRADIENT_COLOUR = object
RIBBON_ART_TOOLBAR_BORDER_COLOUR = object
RIBBON_ART_TOOLBAR_FACE_COLOUR = object
RIBBON_ART_TOOLBAR_HOVER_BORDER_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_GROUP_SEPARATION_SIZE = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_BAR_ALWAYS_SHOW_TABS = object
RIBBON_BAR_DEFAULT_STYLE = object
RIBBON_BAR_EXPANDED = object
RIBBON_BAR_FLOW_HORIZONTAL = object
RIBBON_BAR_FLOW_VERTICAL = object
RIBBON_BAR_FOLDBAR_STYLE = object
RIBBON_BAR_MINIMIZED = object
RIBBON_BAR_PINNED = object
RIBBON_BAR_SHOW_HELP_BUTTON = object
RIBBON_BAR_SHOW_PAGE_ICONS = object
RIBBON_BAR_SHOW_PAGE_LABELS = object
RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS = object
RIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS = object
RIBBON_BAR_SHOW_TOGGLE_BUTTON = object
RIBBON_BUTTONBAR_BUTTON_ACTIVE_MASK = object
RIBBON_BUTTONBAR_BUTTON_DISABLED = object
RIBBON_BUTTONBAR_BUTTON_DROPDOWN_ACTIVE = object
RIBBON_BUTTONBAR_BUTTON_DROPDOWN_HOVERED = object
RIBBON_BUTTONBAR_BUTTON_HOVER_MASK = object
RIBBON_BUTTONBAR_BUTTON_LARGE = object
RIBBON_BUTTONBAR_BUTTON_MEDIUM = object
RIBBON_BUTTONBAR_BUTTON_NORMAL_ACTIVE = object
RIBBON_BUTTONBAR_BUTTON_NORMAL_HOVERED = object
RIBBON_BUTTONBAR_BUTTON_SIZE_MASK = object
RIBBON_BUTTONBAR_BUTTON_SMALL = object
RIBBON_BUTTONBAR_BUTTON_STATE_MASK = object
RIBBON_BUTTONBAR_BUTTON_TOGGLED = object
RIBBON_BUTTON_DROPDOWN = object
RIBBON_BUTTON_HYBRID = object
RIBBON_BUTTON_NORMAL = object
RIBBON_BUTTON_TOGGLE = object
RIBBON_GALLERY_BUTTON_ACTIVE = object
RIBBON_GALLERY_BUTTON_DISABLED = object
RIBBON_GALLERY_BUTTON_HOVERED = object
RIBBON_GALLERY_BUTTON_NORMAL = object
RIBBON_PANEL_DEFAULT_STYLE = object
RIBBON_PANEL_EXT_BUTTON = object
RIBBON_PANEL_FLEXIBLE = object
RIBBON_PANEL_MINIMISE_BUTTON = object
RIBBON_PANEL_NO_AUTO_MINIMISE = object
RIBBON_PANEL_STRETCH = object
RIBBON_SCROLL_BTN_ACTIVE = object
RIBBON_SCROLL_BTN_DIRECTION_MASK = object
RIBBON_SCROLL_BTN_DOWN = object
RIBBON_SCROLL_BTN_FOR_MASK = object
RIBBON_SCROLL_BTN_FOR_OTHER = object
RIBBON_SCROLL_BTN_FOR_PAGE = object
RIBBON_SCROLL_BTN_FOR_TABS = object
RIBBON_SCROLL_BTN_HOVERED = object
RIBBON_SCROLL_BTN_LEFT = object
RIBBON_SCROLL_BTN_NORMAL = object
RIBBON_SCROLL_BTN_RIGHT = object
RIBBON_SCROLL_BTN_STATE_MASK = object
RIBBON_SCROLL_BTN_UP = object
RibbonAUIArtProvider = object
RibbonArtProvider = object
RibbonArtSetting = object
RibbonBar = object
RibbonBarEvent = object
RibbonBarOption = object
RibbonButtonBar = object
RibbonButtonBarButtonBase = object
RibbonButtonBarButtonState = object
RibbonButtonBarEvent = object
RibbonButtonKind = object
RibbonControl = object
RibbonDefaultArtProvider = object
RibbonDisplayMode = object
RibbonGallery = object
RibbonGalleryButtonState = object
RibbonGalleryEvent = object
RibbonGalleryItem = object
RibbonMSWArtProvider = object
RibbonPage = object
RibbonPageTabInfo = object
RibbonPageTabInfoArray = object
RibbonPanel = object
RibbonPanelEvent = object
RibbonPanelOption = object
RibbonScrollButtonStyle = object
RibbonToolBar = object
RibbonToolBarEvent = object
RibbonToolBarToolBase = object
wxEVT_RIBBONBAR_HELP_CLICK = 0
wxEVT_RIBBONBAR_PAGE_CHANGED = 0
wxEVT_RIBBONBAR_PAGE_CHANGING = 0
wxEVT_RIBBONBAR_TAB_LEFT_DCLICK = 0
wxEVT_RIBBONBAR_TAB_MIDDLE_DOWN = 0
wxEVT_RIBBONBAR_TAB_MIDDLE_UP = 0
wxEVT_RIBBONBAR_TAB_RIGHT_DOWN = 0
wxEVT_RIBBONBAR_TAB_RIGHT_UP = 0
wxEVT_RIBBONBAR_TOGGLED = 0
wxEVT_RIBBONBUTTONBAR_CLICKED = 0
wxEVT_RIBBONBUTTONBAR_DROPDOWN_CLICKED = 0
wxEVT_RIBBONGALLERY_CLICKED = 0
wxEVT_RIBBONGALLERY_HOVER_CHANGED = 0
wxEVT_RIBBONGALLERY_SELECTED = 0
wxEVT_RIBBONPANEL_EXTBUTTON_ACTIVATED = 0
wxEVT_RIBBONTOOLBAR_CLICKED = 0
wxEVT_RIBBONTOOLBAR_DROPDOWN_CLICKED = 0
