# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AdjustAlpha = dummy_function
AdjustColour = dummy_function
BestLabelColour = dummy_function
EVT_PLATEBTN_DROPARROW_PRESSED = object
GetHighlightColour = dummy_function
PB_STYLE_DEFAULT = 0
PB_STYLE_DROPARROW = 0
PB_STYLE_GRADIENT = 0
PB_STYLE_NOBG = 0
PB_STYLE_SQUARE = 0
PB_STYLE_TOGGLE = 0
PLATE_HIGHLIGHT = 0
PLATE_NORMAL = 0
PLATE_PRESSED = 0
PlateBtnDropArrowPressed = object
PlateButton = object
