# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EventAdapter = object
EventMacroInfo = object
EventManager = object
FakeWindow = object
MessageAdapter = object
_macroInfo = object
eventManager = object
