# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AEDIALOG_STYLE = 0
ArrayPGProperty = object
ArrayStringProperty = object
BoolProperty = object
ColourProperty = object
ColourPropertyValue = object
CursorProperty = object
DateProperty = object
DirProperty = object
EVT_PG_CHANGED = object
EVT_PG_CHANGING = object
EVT_PG_COL_BEGIN_DRAG = object
EVT_PG_COL_DRAGGING = object
EVT_PG_COL_END_DRAG = object
EVT_PG_DOUBLE_CLICK = object
EVT_PG_HIGHLIGHTED = object
EVT_PG_ITEM_COLLAPSED = object
EVT_PG_ITEM_EXPANDED = object
EVT_PG_LABEL_EDIT_BEGIN = object
EVT_PG_LABEL_EDIT_ENDING = object
EVT_PG_PAGE_CHANGED = object
EVT_PG_RIGHT_CLICK = object
EVT_PG_SELECTED = object
EditEnumProperty = object
EnumProperty = object
FileProperty = object
FlagsProperty = object
FloatProperty = object
FontProperty = object
ImageFileProperty = object
IntProperty = object
LongStringProperty = object
MultiChoiceProperty = object
NullProperty = None
NumericPropertyValidator = object
PGArrayEditorDialog = object
PGArrayStringEditorDialog = object
PGCell = object
PGCellData = object
PGCellRenderer = object
PGCheckBoxEditor = object
PGChoiceAndButtonEditor = object
PGChoiceEditor = object
PGChoiceEntry = object
PGChoices = object
PGChoicesData = object
PGChoicesEmptyData = None
PGComboBoxEditor = object
PGDefaultRenderer = object
PGEditor = object
PGEditorDialogAdapter = object
PGEditor_CheckBox = object
PGEditor_Choice = object
PGEditor_ChoiceAndButton = object
PGEditor_ComboBox = object
PGEditor_DatePickerCtrl = object
PGEditor_SpinCtrl = object
PGEditor_TextCtrl = object
PGEditor_TextCtrlAndButton = object
PGFileDialogAdapter = object
PGGetDefaultImageWildcard = dummy_function
PGInDialogValidator = object
PGLongStringDialogAdapter = object
PGMAN_DEFAULT_STYLE = 0
PGMultiButton = object
PGNumericValidationConstants = object
PGPaintData = object
PGPropArgCls = object
PGProperty = object
PGPropertyFlags = object
PGSpinCtrlEditor = object
PGTextCtrlAndButtonEditor = object
PGTextCtrlEditor = object
PGVIterator = object
PGValidationInfo = object
PGWindowList = object
PG_ACTION_CANCEL_EDIT = object
PG_ACTION_COLLAPSE_PROPERTY = object
PG_ACTION_EDIT = object
PG_ACTION_EXPAND_PROPERTY = object
PG_ACTION_INVALID = object
PG_ACTION_MAX = object
PG_ACTION_NEXT_PROPERTY = object
PG_ACTION_PRESS_BUTTON = object
PG_ACTION_PREV_PROPERTY = object
PG_ALPHABETIC_MODE = object
PG_ARRAY_DELIMITER = ''
PG_ATTR_AUTOCOMPLETE = ''
PG_ATTR_DEFAULT_VALUE = ''
PG_ATTR_HINT = ''
PG_ATTR_INLINE_HELP = ''
PG_ATTR_MAX = ''
PG_ATTR_MIN = ''
PG_ATTR_MULTICHOICE_USERSTRINGMODE = ''
PG_ATTR_SPINCTRL_MOTIONSPIN = ''
PG_ATTR_SPINCTRL_STEP = ''
PG_ATTR_SPINCTRL_WRAP = ''
PG_ATTR_UNITS = ''
PG_AUTO_SORT = object
PG_BASE_DEC = 0
PG_BASE_HEX = 0
PG_BASE_HEXL = 0
PG_BASE_OCT = 0
PG_BOLD_MODIFIED = object
PG_BOOL_USE_CHECKBOX = ''
PG_BOOL_USE_DOUBLE_CLICK_CYCLING = ''
PG_CAPRECTXMARGIN = 0
PG_CAPRECTYMARGIN = 0
PG_COLOUR_ALLOW_CUSTOM = ''
PG_COLOUR_BLACK = object
PG_COLOUR_CUSTOM = 0
PG_COLOUR_HAS_ALPHA = ''
PG_COLOUR_UNSPECIFIED = 0
PG_COLOUR_WEB_BASE = 0
PG_COMPOSITE_FRAGMENT = object
PG_CUSTOM_IMAGE_SPACINGY = 0
PG_DATE_FORMAT = ''
PG_DATE_PICKER_STYLE = ''
PG_DEFAULT_IMAGE_SIZE = object
PG_DEFAULT_STYLE = 0
PG_DESCRIPTION = object
PG_DIR_DIALOG_MESSAGE = ''
PG_DONT_RECURSE = 0
PG_EDITABLE_VALUE = object
PG_EX_AUTO_UNSPECIFIED_VALUES = object
PG_EX_ENABLE_TLP_TRACKING = object
PG_EX_HELP_AS_TOOLTIPS = object
PG_EX_HIDE_PAGE_BUTTONS = object
PG_EX_INIT_NOCAT = object
PG_EX_MODE_BUTTONS = object
PG_EX_MULTIPLE_SELECTION = object
PG_EX_NATIVE_DOUBLE_BUFFERING = object
PG_EX_NO_FLAT_TOOLBAR = object
PG_EX_NO_TOOLBAR_DIVIDER = object
PG_EX_TOOLBAR_SEPARATOR = object
PG_EX_WINDOW_STYLES = object
PG_EX_WRITEONLY_BUILTIN_ATTRIBUTES = object
PG_FILE_DIALOG_STYLE = ''
PG_FILE_DIALOG_TITLE = ''
PG_FILE_INITIAL_PATH = ''
PG_FILE_SHOW_FULL_PATH = ''
PG_FILE_SHOW_RELATIVE_PATH = ''
PG_FILE_WILDCARD = ''
PG_FLOAT_PRECISION = ''
PG_FORCE = object
PG_FULL_VALUE = object
PG_GETPROPERTYVALUES_FLAGS = object
PG_HIDE_CATEGORIES = object
PG_HIDE_MARGIN = object
PG_INC_ATTRIBUTES = object
PG_INVALID_VALUE = 0
PG_ITERATE_ALL = object
PG_ITERATE_ALL_PARENTS = object
PG_ITERATE_ALL_PARENTS_RECURSIVELY = object
PG_ITERATE_CATEGORIES = object
PG_ITERATE_DEFAULT = object
PG_ITERATE_FIXED_CHILDREN = object
PG_ITERATE_HIDDEN = object
PG_ITERATE_NORMAL = object
PG_ITERATE_PROPERTIES = object
PG_ITERATE_VISIBLE = object
PG_ITERATOR_FLAGS = object
PG_ITERATOR_FLAGS_ALL = object
PG_ITERATOR_MASK_OP_ITEM = object
PG_ITERATOR_MASK_OP_PARENT = object
PG_KEEP_STRUCTURE = object
PG_KEYBOARD_ACTIONS = object
PG_LABEL = ''
PG_LABEL_STRING = ''
PG_LIMITED_EDITING = object
PG_MISC_ARG_FLAGS = object
PG_NO_INTERNAL_BORDER = object
PG_NULL_BITMAP = object
PG_PREFIX_0x = 0
PG_PREFIX_DOLLAR_SIGN = 0
PG_PREFIX_NONE = 0
PG_PROGRAMMATIC_VALUE = object
PG_PROPERTY_SPECIFIC = object
PG_PROPERTY_VALIDATION_ERROR_MESSAGE = object
PG_PROPERTY_VALIDATION_SATURATE = object
PG_PROPERTY_VALIDATION_WRAP = object
PG_PROP_AGGREGATE = object
PG_PROP_AUTO_UNSPECIFIED = object
PG_PROP_BEING_DELETED = object
PG_PROP_CATEGORY = object
PG_PROP_CHILDREN_ARE_COPIES = object
PG_PROP_CLASS_SPECIFIC_1 = object
PG_PROP_CLASS_SPECIFIC_2 = object
PG_PROP_COLLAPSED = object
PG_PROP_COMPOSED_VALUE = object
PG_PROP_CUSTOMIMAGE = object
PG_PROP_DISABLED = object
PG_PROP_HIDDEN = object
PG_PROP_INVALID_VALUE = object
PG_PROP_MAX = 0
PG_PROP_MISC_PARENT = object
PG_PROP_MODIFIED = object
PG_PROP_NOEDITOR = object
PG_PROP_NO_ESCAPE = 0
PG_PROP_PARENTAL_FLAGS = 0
PG_PROP_PASSWORD = 0
PG_PROP_PROPERTY = object
PG_PROP_READONLY = object
PG_PROP_SHOW_FULL_FILENAME = 0
PG_PROP_STATIC_CHOICES = 0
PG_PROP_TRANSLATE_CUSTOM = 0
PG_PROP_USES_COMMON_VALUE = object
PG_PROP_USE_CHECKBOX = 0
PG_PROP_USE_DCC = 0
PG_PROP_WAS_MODIFIED = object
PG_RECURSE = object
PG_RECURSE_STARTS = object
PG_REPORT_ERROR = object
PG_SETVALUE_FLAGS = object
PG_SETVAL_AGGREGATED = object
PG_SETVAL_BY_USER = object
PG_SETVAL_FROM_PARENT = object
PG_SETVAL_REFRESH_EDITOR = object
PG_SORT_TOP_LEVEL_ONLY = object
PG_SPLITTER_AUTO_CENTER = object
PG_STATIC_LAYOUT = object
PG_STATIC_SPLITTER = object
PG_STRING_PASSWORD = ''
PG_SUBID1 = 0
PG_SUBID2 = 0
PG_SUBID_TEMP1 = 0
PG_TOOLBAR = object
PG_TOOLTIPS = object
PG_UINT_BASE = ''
PG_UINT_PREFIX = ''
PG_UNEDITABLE_COMPOSITE_FRAGMENT = object
PG_VALIDATION_FAILURE_BEHAVIOR_FLAGS = object
PG_VALUE_IS_CURRENT = object
PG_VFB_BEEP = object
PG_VFB_DEFAULT = object
PG_VFB_MARK_CELL = object
PG_VFB_SHOW_MESSAGE = object
PG_VFB_SHOW_MESSAGEBOX = object
PG_VFB_SHOW_MESSAGE_ON_STATUSBAR = object
PG_VFB_STAY_IN_PROPERTY = object
PG_WINDOW_STYLES = object
PropertyCategory = object
PropertyGrid = object
PropertyGridEvent = object
PropertyGridHitTestResult = object
PropertyGridInterface = object
PropertyGridIterator = object
PropertyGridIteratorBase = object
PropertyGridManager = object
PropertyGridManagerNameStr = bytes()
PropertyGridNameStr = bytes()
PropertyGridPage = object
PropertyGridPageState = object
PyArrayStringProperty = object
PyChoiceEditor = object
PyColourProperty = object
PyComboBoxEditor = object
PyEditEnumProperty = object
PyEditor = object
PyEditorDialogAdapter = object
PyEnumProperty = object
PyFileDialogAdapter = object
PyFileProperty = object
PyFlagsProperty = object
PyFloatProperty = object
PyFontProperty = object
PyIntProperty = object
PyLongStringDialogAdapter = object
PyLongStringProperty = object
PyProperty = object
PyStringProperty = object
PySystemColourProperty = object
PyTextCtrlEditor = object
PyUIntProperty = object
RegisterEditor = dummy_function
StringProperty = object
SystemColourProperty = object
UIntProperty = object
_PropertyGridManager__init__ = dummy_function
_PropertyGrid__init__ = dummy_function
_type2property = None
_vt2getter = None
testPGVariantTypeName = dummy_function
testPGVariantTypemap = dummy_function
wxEVT_PG_CHANGED = 0
wxEVT_PG_CHANGING = 0
wxEVT_PG_COL_BEGIN_DRAG = 0
wxEVT_PG_COL_DRAGGING = 0
wxEVT_PG_COL_END_DRAG = 0
wxEVT_PG_DOUBLE_CLICK = 0
wxEVT_PG_HIGHLIGHTED = 0
wxEVT_PG_ITEM_COLLAPSED = 0
wxEVT_PG_ITEM_EXPANDED = 0
wxEVT_PG_LABEL_EDIT_BEGIN = 0
wxEVT_PG_LABEL_EDIT_ENDING = 0
wxEVT_PG_PAGE_CHANGED = 0
wxEVT_PG_RIGHT_CLICK = 0
wxEVT_PG_SELECTED = 0
