# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CollapseTree = object
EvtWatcher = object
ExpandTree = object
Find = object
FlagsFormatter = object
HighlightItem = object
Icon = object
InspectionFrame = object
InspectionInfoPanel = object
InspectionTool = object
InspectionTree = object
PyEmbeddedImage = object
Refresh = object
ShowFilling = object
ShowSizers = object
TreeBaseClass = object
_InspectionHighlighter = object
flexmodeFlags = dict()
itemFlags = dict()
orientFlags = dict()
