# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


MultiSplitterEvent = object
MultiSplitterWindow = object
_RENDER_VER = tuple()
