# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_GRID_CELL_BEGIN_DRAG = object
EVT_GRID_CELL_CHANGED = object
EVT_GRID_CELL_CHANGING = object
EVT_GRID_CELL_LEFT_CLICK = object
EVT_GRID_CELL_LEFT_DCLICK = object
EVT_GRID_CELL_RIGHT_CLICK = object
EVT_GRID_CELL_RIGHT_DCLICK = object
EVT_GRID_CMD_CELL_BEGIN_DRAG = object
EVT_GRID_CMD_CELL_CHANGED = object
EVT_GRID_CMD_CELL_CHANGING = object
EVT_GRID_CMD_CELL_LEFT_CLICK = object
EVT_GRID_CMD_CELL_LEFT_DCLICK = object
EVT_GRID_CMD_CELL_RIGHT_CLICK = object
EVT_GRID_CMD_CELL_RIGHT_DCLICK = object
EVT_GRID_CMD_COL_MOVE = object
EVT_GRID_CMD_COL_SIZE = object
EVT_GRID_CMD_COL_SORT = object
EVT_GRID_CMD_EDITOR_CREATED = object
EVT_GRID_CMD_EDITOR_HIDDEN = object
EVT_GRID_CMD_EDITOR_SHOWN = object
EVT_GRID_CMD_LABEL_LEFT_CLICK = object
EVT_GRID_CMD_LABEL_LEFT_DCLICK = object
EVT_GRID_CMD_LABEL_RIGHT_CLICK = object
EVT_GRID_CMD_LABEL_RIGHT_DCLICK = object
EVT_GRID_CMD_RANGE_SELECT = object
EVT_GRID_CMD_ROW_SIZE = object
EVT_GRID_CMD_SELECT_CELL = object
EVT_GRID_CMD_TABBING = object
EVT_GRID_COL_MOVE = object
EVT_GRID_COL_SIZE = object
EVT_GRID_COL_SORT = object
EVT_GRID_EDITOR_CREATED = object
EVT_GRID_EDITOR_HIDDEN = object
EVT_GRID_EDITOR_SHOWN = object
EVT_GRID_LABEL_LEFT_CLICK = object
EVT_GRID_LABEL_LEFT_DCLICK = object
EVT_GRID_LABEL_RIGHT_CLICK = object
EVT_GRID_LABEL_RIGHT_DCLICK = object
EVT_GRID_RANGE_SELECT = object
EVT_GRID_ROW_SIZE = object
EVT_GRID_SELECT_CELL = object
EVT_GRID_TABBING = object
GRIDTABLE_NOTIFY_COLS_APPENDED = object
GRIDTABLE_NOTIFY_COLS_DELETED = object
GRIDTABLE_NOTIFY_COLS_INSERTED = object
GRIDTABLE_NOTIFY_ROWS_APPENDED = object
GRIDTABLE_NOTIFY_ROWS_DELETED = object
GRIDTABLE_NOTIFY_ROWS_INSERTED = object
GRIDTABLE_REQUEST_VIEW_GET_VALUES = object
GRIDTABLE_REQUEST_VIEW_SEND_VALUES = object
GRID_AUTOSIZE = 0
GRID_COLUMN = object
GRID_DRAW_BOX_RECT = object
GRID_DRAW_CELL_LINES = object
GRID_DRAW_COLS_HEADER = object
GRID_DRAW_DEFAULT = object
GRID_DRAW_ROWS_HEADER = object
GRID_DRAW_SELECTION = object
GRID_FLOAT_FORMAT_COMPACT = object
GRID_FLOAT_FORMAT_DEFAULT = object
GRID_FLOAT_FORMAT_FIXED = object
GRID_FLOAT_FORMAT_SCIENTIFIC = object
GRID_FLOAT_FORMAT_UPPER = object
GRID_ROW = object
GRID_VALUE_BOOL = ''
GRID_VALUE_CHOICE = ''
GRID_VALUE_CHOICEINT = ''
GRID_VALUE_DATETIME = ''
GRID_VALUE_FLOAT = ''
GRID_VALUE_LONG = ''
GRID_VALUE_NUMBER = ''
GRID_VALUE_STRING = ''
GRID_VALUE_TEXT = ''
Grid = object
GridCellAttr = object
GridCellAttrProvider = object
GridCellAutoWrapStringEditor = object
GridCellAutoWrapStringRenderer = object
GridCellBoolEditor = object
GridCellBoolRenderer = object
GridCellChoiceEditor = object
GridCellCoords = object
GridCellCoordsArray = object
GridCellDateTimeRenderer = object
GridCellEditor = object
GridCellEnumEditor = object
GridCellEnumRenderer = object
GridCellFloatEditor = object
GridCellFloatFormat = object
GridCellFloatRenderer = object
GridCellNumberEditor = object
GridCellNumberRenderer = object
GridCellRenderer = object
GridCellStringRenderer = object
GridCellTextEditor = object
GridColumnHeaderRenderer = object
GridColumnHeaderRendererDefault = object
GridCornerHeaderRenderer = object
GridCornerHeaderRendererDefault = object
GridDirection = object
GridEditorCreatedEvent = object
GridEvent = object
GridHeaderLabelsRenderer = object
GridNameStr = bytes()
GridRangeSelectEvent = object
GridRenderStyle = object
GridRowHeaderRenderer = object
GridRowHeaderRendererDefault = object
GridSizeEvent = object
GridSizesInfo = object
GridStringTable = object
GridTableBase = object
GridTableMessage = object
GridTableRequest = object
GridUpdateLocker = object
PyGridCellAttrProvider = object
PyGridCellEditor = object
PyGridCellRenderer = object
PyGridTableBase = object
_im_GridCellCoords = object
wxEVT_GRID_CELL_BEGIN_DRAG = 0
wxEVT_GRID_CELL_CHANGED = 0
wxEVT_GRID_CELL_CHANGING = 0
wxEVT_GRID_CELL_LEFT_CLICK = 0
wxEVT_GRID_CELL_LEFT_DCLICK = 0
wxEVT_GRID_CELL_RIGHT_CLICK = 0
wxEVT_GRID_CELL_RIGHT_DCLICK = 0
wxEVT_GRID_COL_AUTO_SIZE = 0
wxEVT_GRID_COL_MOVE = 0
wxEVT_GRID_COL_SIZE = 0
wxEVT_GRID_COL_SORT = 0
wxEVT_GRID_EDITOR_CREATED = 0
wxEVT_GRID_EDITOR_HIDDEN = 0
wxEVT_GRID_EDITOR_SHOWN = 0
wxEVT_GRID_LABEL_LEFT_CLICK = 0
wxEVT_GRID_LABEL_LEFT_DCLICK = 0
wxEVT_GRID_LABEL_RIGHT_CLICK = 0
wxEVT_GRID_LABEL_RIGHT_DCLICK = 0
wxEVT_GRID_RANGE_SELECT = 0
wxEVT_GRID_ROW_SIZE = 0
wxEVT_GRID_SELECT_CELL = 0
wxEVT_GRID_TABBING = 0
