# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RW_LAYOUT_NEEDED = object
RW_FILL = ''
RW_FILL2 = ''
RW_LENGTH = 0
RW_PEN = ''
RW_THICKNESS = 0
ResizeWidget = object
_RWLayoutNeededEvent = object
