# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_UPDATE_THROBBER = object
THROBBER_EVENT = 0
Throbber = object
UpdateThrobberEvent = object
