# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Date = object
FillDate = dummy_function
FormatDay = dummy_function
FromJulian = dummy_function
Month = dict()
TodayDay = dummy_function
_ = dummy_function
dayOfWeek = dummy_function
day_abbr = []
day_name = []
daysPerMonth = dummy_function
isleap = dummy_function
julianDay = dummy_function
leapdays = dummy_function
mdays = []
now = object
