# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


_min_adobe_version = None
get_acroversion = dummy_function
get_min_adobe_version = dummy_function
