# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


GenBitmapButton = object
GenBitmapTextButton = object
GenBitmapTextToggleButton = object
GenBitmapToggleButton = object
GenButton = object
GenButtonEvent = object
GenToggleButton = object
ThemedGenBitmapButton = object
ThemedGenBitmapTextButton = object
ThemedGenBitmapTextToggleButton = object
ThemedGenBitmapToggleButton = object
ThemedGenButton = object
ThemedGenToggleButton = object
__ThemedMixin = object
__ToggleMixin = object
