# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AUI_BUTTON_CLOSE = object
AUI_BUTTON_CUSTOM1 = object
AUI_BUTTON_CUSTOM2 = object
AUI_BUTTON_CUSTOM3 = object
AUI_BUTTON_DOWN = object
AUI_BUTTON_LEFT = object
AUI_BUTTON_MAXIMIZE_RESTORE = object
AUI_BUTTON_MINIMIZE = object
AUI_BUTTON_OPTIONS = object
AUI_BUTTON_PIN = object
AUI_BUTTON_RIGHT = object
AUI_BUTTON_STATE_CHECKED = object
AUI_BUTTON_STATE_DISABLED = object
AUI_BUTTON_STATE_HIDDEN = object
AUI_BUTTON_STATE_HOVER = object
AUI_BUTTON_STATE_NORMAL = object
AUI_BUTTON_STATE_PRESSED = object
AUI_BUTTON_UP = object
AUI_BUTTON_WINDOWLIST = object
AUI_DOCKART_ACTIVE_CAPTION_COLOUR = object
AUI_DOCKART_ACTIVE_CAPTION_GRADIENT_COLOUR = object
AUI_DOCKART_ACTIVE_CAPTION_TEXT_COLOUR = object
AUI_DOCKART_BACKGROUND_COLOUR = object
AUI_DOCKART_BORDER_COLOUR = object
AUI_DOCKART_CAPTION_FONT = object
AUI_DOCKART_CAPTION_SIZE = object
AUI_DOCKART_GRADIENT_TYPE = object
AUI_DOCKART_GRIPPER_COLOUR = object
AUI_DOCKART_GRIPPER_SIZE = object
AUI_DOCKART_INACTIVE_CAPTION_COLOUR = object
AUI_DOCKART_INACTIVE_CAPTION_GRADIENT_COLOUR = object
AUI_DOCKART_INACTIVE_CAPTION_TEXT_COLOUR = object
AUI_DOCKART_PANE_BORDER_SIZE = object
AUI_DOCKART_PANE_BUTTON_SIZE = object
AUI_DOCKART_SASH_COLOUR = object
AUI_DOCKART_SASH_SIZE = object
AUI_DOCK_BOTTOM = object
AUI_DOCK_CENTER = object
AUI_DOCK_CENTRE = object
AUI_DOCK_LEFT = object
AUI_DOCK_NONE = object
AUI_DOCK_RIGHT = object
AUI_DOCK_TOP = object
AUI_GRADIENT_HORIZONTAL = object
AUI_GRADIENT_NONE = object
AUI_GRADIENT_VERTICAL = object
AUI_MGR_ALLOW_ACTIVE_PANE = object
AUI_MGR_ALLOW_FLOATING = object
AUI_MGR_DEFAULT = object
AUI_MGR_HINT_FADE = object
AUI_MGR_LIVE_RESIZE = object
AUI_MGR_NO_VENETIAN_BLINDS_FADE = object
AUI_MGR_RECTANGLE_HINT = object
AUI_MGR_TRANSPARENT_DRAG = object
AUI_MGR_TRANSPARENT_HINT = object
AUI_MGR_VENETIAN_BLINDS_HINT = object
AUI_NB_BOTTOM = object
AUI_NB_CLOSE_BUTTON = object
AUI_NB_CLOSE_ON_ACTIVE_TAB = object
AUI_NB_CLOSE_ON_ALL_TABS = object
AUI_NB_DEFAULT_STYLE = object
AUI_NB_LEFT = object
AUI_NB_MIDDLE_CLICK_CLOSE = object
AUI_NB_RIGHT = object
AUI_NB_SCROLL_BUTTONS = object
AUI_NB_TAB_EXTERNAL_MOVE = object
AUI_NB_TAB_FIXED_WIDTH = object
AUI_NB_TAB_MOVE = object
AUI_NB_TAB_SPLIT = object
AUI_NB_TOP = object
AUI_NB_WINDOWLIST_BUTTON = object
AUI_ORIENTATION_MASK = object
AUI_TBART_GRIPPER_SIZE = object
AUI_TBART_OVERFLOW_SIZE = object
AUI_TBART_SEPARATOR_SIZE = object
AUI_TBTOOL_TEXT_BOTTOM = object
AUI_TBTOOL_TEXT_LEFT = object
AUI_TBTOOL_TEXT_RIGHT = object
AUI_TBTOOL_TEXT_TOP = object
AUI_TB_DEFAULT_STYLE = object
AUI_TB_GRIPPER = object
AUI_TB_HORIZONTAL = object
AUI_TB_HORZ_LAYOUT = object
AUI_TB_HORZ_TEXT = object
AUI_TB_NO_AUTORESIZE = object
AUI_TB_NO_TOOLTIPS = object
AUI_TB_OVERFLOW = object
AUI_TB_PLAIN_BACKGROUND = object
AUI_TB_TEXT = object
AUI_TB_VERTICAL = object
AuiButtonId = object
AuiDefaultDockArt = object
AuiDefaultTabArt = object
AuiDefaultToolBarArt = object
AuiDockArt = object
AuiDockInfo = object
AuiDockInfoArray = object
AuiDockInfoPtrArray = object
AuiDockUIPart = object
AuiDockUIPartArray = object
AuiMDIChildFrame = object
AuiMDIClientWindow = object
AuiMDIParentFrame = object
AuiManager = object
AuiManagerDock = object
AuiManagerEvent = object
AuiManagerOption = object
AuiNotebook = object
AuiNotebookEvent = object
AuiNotebookOption = object
AuiNotebookPage = object
AuiNotebookPageArray = object
AuiPaneButton = object
AuiPaneButtonArray = object
AuiPaneButtonState = object
AuiPaneDockArtGradients = object
AuiPaneDockArtSetting = object
AuiPaneInfo = object
AuiPaneInfoArray = object
AuiPaneInfoPtrArray = object
AuiSimpleTabArt = object
AuiTabArt = object
AuiTabContainer = object
AuiTabContainerButton = object
AuiTabContainerButtonArray = object
AuiTabCtrl = object
AuiToolBar = object
AuiToolBarArt = object
AuiToolBarArtSetting = object
AuiToolBarEvent = object
AuiToolBarItem = object
AuiToolBarItemArray = object
AuiToolBarStyle = object
AuiToolBarToolTextOrientation = object
EVT_AUINOTEBOOK_ALLOW_DND = object
EVT_AUINOTEBOOK_BEGIN_DRAG = object
EVT_AUINOTEBOOK_BG_DCLICK = object
EVT_AUINOTEBOOK_BUTTON = object
EVT_AUINOTEBOOK_DRAG_DONE = object
EVT_AUINOTEBOOK_DRAG_MOTION = object
EVT_AUINOTEBOOK_END_DRAG = object
EVT_AUINOTEBOOK_PAGE_CHANGED = object
EVT_AUINOTEBOOK_PAGE_CHANGING = object
EVT_AUINOTEBOOK_PAGE_CLOSE = object
EVT_AUINOTEBOOK_PAGE_CLOSED = object
EVT_AUINOTEBOOK_TAB_MIDDLE_DOWN = object
EVT_AUINOTEBOOK_TAB_MIDDLE_UP = object
EVT_AUINOTEBOOK_TAB_RIGHT_DOWN = object
EVT_AUINOTEBOOK_TAB_RIGHT_UP = object
EVT_AUITOOLBAR_BEGIN_DRAG = object
EVT_AUITOOLBAR_MIDDLE_CLICK = object
EVT_AUITOOLBAR_OVERFLOW_CLICK = object
EVT_AUITOOLBAR_RIGHT_CLICK = object
EVT_AUITOOLBAR_TOOL_DROPDOWN = object
EVT_AUI_FIND_MANAGER = object
EVT_AUI_PANE_ACTIVATED = object
EVT_AUI_PANE_BUTTON = object
EVT_AUI_PANE_CLOSE = object
EVT_AUI_PANE_MAXIMIZE = object
EVT_AUI_PANE_RESTORE = object
EVT_AUI_RENDER = object
wxEVT_AUINOTEBOOK_ALLOW_DND = 0
wxEVT_AUINOTEBOOK_BEGIN_DRAG = 0
wxEVT_AUINOTEBOOK_BG_DCLICK = 0
wxEVT_AUINOTEBOOK_BUTTON = 0
wxEVT_AUINOTEBOOK_DRAG_DONE = 0
wxEVT_AUINOTEBOOK_DRAG_MOTION = 0
wxEVT_AUINOTEBOOK_END_DRAG = 0
wxEVT_AUINOTEBOOK_PAGE_CHANGED = 0
wxEVT_AUINOTEBOOK_PAGE_CHANGING = 0
wxEVT_AUINOTEBOOK_PAGE_CLOSE = 0
wxEVT_AUINOTEBOOK_PAGE_CLOSED = 0
wxEVT_AUINOTEBOOK_TAB_MIDDLE_DOWN = 0
wxEVT_AUINOTEBOOK_TAB_MIDDLE_UP = 0
wxEVT_AUINOTEBOOK_TAB_RIGHT_DOWN = 0
wxEVT_AUINOTEBOOK_TAB_RIGHT_UP = 0
wxEVT_AUITOOLBAR_BEGIN_DRAG = 0
wxEVT_AUITOOLBAR_MIDDLE_CLICK = 0
wxEVT_AUITOOLBAR_OVERFLOW_CLICK = 0
wxEVT_AUITOOLBAR_RIGHT_CLICK = 0
wxEVT_AUITOOLBAR_TOOL_DROPDOWN = 0
wxEVT_AUI_FIND_MANAGER = 0
wxEVT_AUI_PANE_ACTIVATED = 0
wxEVT_AUI_PANE_BUTTON = 0
wxEVT_AUI_PANE_CLOSE = 0
wxEVT_AUI_PANE_MAXIMIZE = 0
wxEVT_AUI_PANE_RESTORE = 0
wxEVT_AUI_RENDER = 0
