# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CR_SIZE = 0
DrawSash = dummy_function
EmptyChild = object
MV_HOR = 0
MultiClient = object
MultiCloser = object
MultiCreator = object
MultiSash = object
MultiSizer = object
MultiSplit = object
MultiViewLeaf = object
SH_SIZE = 0
