# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AboutDialog = object
AboutService = object
Blank = object
ChildDocTemplate = object
ChildDocument = object
Copy = object
Cut = object
DocApp = object
DocFrameMixIn = object
DocMDIChildFrame = object
DocMDIParentFrame = object
DocMDIParentFrameMixIn = object
DocOptionsService = object
DocSDIFrame = object
DocService = object
DocTabbedChildFrame = object
DocTabbedParentFrame = object
EMBEDDED_WINDOW_ALL = 0
EMBEDDED_WINDOW_BOTTOM = 0
EMBEDDED_WINDOW_BOTTOMLEFT = 0
EMBEDDED_WINDOW_BOTTOMRIGHT = 0
EMBEDDED_WINDOW_LEFT = 0
EMBEDDED_WINDOW_RIGHT = 0
EMBEDDED_WINDOW_TOP = 0
EMBEDDED_WINDOW_TOPLEFT = 0
EMBEDDED_WINDOW_TOPRIGHT = 0
FilePropertiesDialog = object
FilePropertiesService = object
GeneralOptionsPanel = object
New = object
Open = object
OptionsDialog = object
Paste = object
Print = object
PrintPreview = object
PyEmbeddedImage = object
Redo = object
RowColSizer = object
SAVEALL_ID = object
Save = object
SaveAll = object
Undo = object
VIEW_STATUSBAR_ID = object
VIEW_TOOLBAR_ID = object
WINDOW_MENU_NUM_ITEMS = 0
WindowMenuService = object
_ = dummy_function
_DocFrameFileDropTarget = object
getBlankIcon = dummy_function
