# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_IP_SELECTION_CHANGED = object
IP_DEFAULT_STYLE = 0
IP_REMOVE_FROM_CHOICES = 0
IP_SORT_CHOICES = 0
IP_SORT_SELECTED = 0
IpSelectionChanged = object
ItemsPicker = object
LB_STYLE = 0
wxEVT_IP_SELECTION_CHANGED = 0
