# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BAD_IMAGE = 0
BitmapButton = object
ConvertBMP = dummy_function
FindFiles = object
GetCheckeredBitmap = dummy_function
GetNamedBitmap = dummy_function
ID_BLACK_BG = object
ID_BOX_FRAME = object
ID_CHECK_BG = object
ID_CROP_FRAME = object
ID_GREY_BG = object
ID_NO_FRAME = object
ID_WHITE_BG = object
IMG_CATALOG = dict()
ImageDialog = object
ImagePanel = object
ImageView = object
PyEmbeddedImage = object
_ = dummy_function
