# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BaseComboTreeBox = object
BasePopupFrame = object
ComboTreeBox = dummy_function
GTKComboTreeBox = object
GTKPopupFrame = object
IterableTreeCtrl = object
MACComboTreeBox = object
MACPopupFrame = object
MSWComboTreeBox = object
MSWPopupFrame = object
NativeComboTreeBox = object
