# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Command = object
CommandProcessor = object
DEFAULT_DOCMAN_FLAGS = 0
DEFAULT_TEMPLATE_FLAGS = 0
DOC_MDI = 0
DOC_NEW = 0
DOC_NO_VIEW = 0
DOC_OPEN_ONCE = 0
DOC_SDI = 0
DOC_SILENT = 0
DocChildFrame = object
DocMDIChildFrame = object
DocMDIParentFrame = object
DocManager = object
DocParentFrame = object
DocPrintout = object
DocTemplate = object
Document = object
FileExists = dummy_function
FileNameFromPath = dummy_function
FindExtension = dummy_function
MAX_FILE_HISTORY = 0
PathOnly = dummy_function
TEMPLATE_INVISIBLE = 0
TEMPLATE_NO_CREATE = 0
TEMPLATE_VISIBLE = 0
View = object
_ = dummy_function
cmp_to_key = dummy_function
