# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DialogResults = object
MultiMessageBox = dummy_function
MultiMessageDialog = object
MultipleChoiceDialog = object
ScrolledMessageDialog = object
alertDialog = dummy_function
colorDialog = dummy_function
colourDialog = dummy_function
dirDialog = dummy_function
directoryDialog = dummy_function
fileDialog = dummy_function
findDialog = dummy_function
fontDialog = dummy_function
messageDialog = dummy_function
multipleChoiceDialog = dummy_function
openFileDialog = dummy_function
returnedString = dummy_function
saveFileDialog = dummy_function
scrolledMessageDialog = dummy_function
singleChoiceDialog = dummy_function
textEntryDialog = dummy_function
