# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


GetDefaultBorder = dummy_function
GetDefaultPanelBorder = dummy_function
GetDialogBorder = dummy_function
GetHGrow = dummy_function
GetSizerProps = dummy_function
GetVGrow = dummy_function
SetDefaultSizerProps = dummy_function
SetHGrow = dummy_function
SetSizerProp = dummy_function
SetSizerProps = dummy_function
SetVGrow = dummy_function
SizedDialog = object
SizedFrame = object
SizedPanel = object
SizedParent = object
SizedScrolledPanel = object
SizedStaticBox = object
align = dict()
border = dict()
halign = dict()
minsize = dict()
misc_flags = dict()
valign = dict()
