# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DCRenderer = object
GetExtent = dummy_function
GetFullExtent = dummy_function
RenderToBitmap = dummy_function
RenderToDC = dummy_function
RenderToRenderer = dummy_function
Renderer = object
SizeRenderer = object
StaticFancyText = object
_addGreek = dummy_function
_families = dict()
_greekEncoding = ''
_greek_letters = tuple()
_styles = dict()
_weights = dict()
getExtent = dummy_function
iceil = dummy_function
iround = dummy_function
renderToBitmap = dummy_function
renderToDC = dummy_function
test = dummy_function
