# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PI_HIDEINACTIVE = 0
PI_PULSEMODE = 0
ProgressIndicator = object
