# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_WEBVIEW_ERROR = object
EVT_WEBVIEW_LOADED = object
EVT_WEBVIEW_NAVIGATED = object
EVT_WEBVIEW_NAVIGATING = object
EVT_WEBVIEW_NEWWINDOW = object
EVT_WEBVIEW_TITLE_CHANGED = object
USE_WEBVIEW = 0
WEBVIEW_FIND_BACKWARDS = object
WEBVIEW_FIND_DEFAULT = object
WEBVIEW_FIND_ENTIRE_WORD = object
WEBVIEW_FIND_HIGHLIGHT_RESULT = object
WEBVIEW_FIND_MATCH_CASE = object
WEBVIEW_FIND_WRAP = object
WEBVIEW_NAV_ERR_AUTH = object
WEBVIEW_NAV_ERR_CERTIFICATE = object
WEBVIEW_NAV_ERR_CONNECTION = object
WEBVIEW_NAV_ERR_NOT_FOUND = object
WEBVIEW_NAV_ERR_OTHER = object
WEBVIEW_NAV_ERR_REQUEST = object
WEBVIEW_NAV_ERR_SECURITY = object
WEBVIEW_NAV_ERR_USER_CANCELLED = object
WEBVIEW_RELOAD_DEFAULT = object
WEBVIEW_RELOAD_NO_CACHE = object
WEBVIEW_ZOOM_LARGE = object
WEBVIEW_ZOOM_LARGEST = object
WEBVIEW_ZOOM_MEDIUM = object
WEBVIEW_ZOOM_SMALL = object
WEBVIEW_ZOOM_TINY = object
WEBVIEW_ZOOM_TYPE_LAYOUT = object
WEBVIEW_ZOOM_TYPE_TEXT = object
WebView = object
WebViewArchiveHandler = object
WebViewBackendDefault = bytes()
WebViewBackendIE = bytes()
WebViewBackendWebKit = bytes()
WebViewDefaultURLStr = bytes()
WebViewEvent = object
WebViewFSHandler = object
WebViewFactory = object
WebViewFindFlags = object
WebViewHandler = object
WebViewHistoryItem = object
WebViewNameStr = bytes()
WebViewNavigationError = object
WebViewReloadFlags = object
WebViewZoom = object
WebViewZoomType = object
wxEVT_COMMAND_WEBVIEW_ERROR = 0
wxEVT_COMMAND_WEBVIEW_LOADED = 0
wxEVT_COMMAND_WEBVIEW_NAVIGATED = 0
wxEVT_COMMAND_WEBVIEW_NAVIGATING = 0
wxEVT_COMMAND_WEBVIEW_NEWWINDOW = 0
wxEVT_COMMAND_WEBVIEW_TITLE_CHANGED = 0
wxEVT_WEBVIEW_ERROR = 0
wxEVT_WEBVIEW_LOADED = 0
wxEVT_WEBVIEW_NAVIGATED = 0
wxEVT_WEBVIEW_NAVIGATING = 0
wxEVT_WEBVIEW_NEWWINDOW = 0
wxEVT_WEBVIEW_TITLE_CHANGED = 0
