# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RICHTEXT_BUFFER_RESET = object
EVT_RICHTEXT_CHARACTER = object
EVT_RICHTEXT_CONTENT_DELETED = object
EVT_RICHTEXT_CONTENT_INSERTED = object
EVT_RICHTEXT_DELETE = object
EVT_RICHTEXT_FOCUS_OBJECT_CHANGED = object
EVT_RICHTEXT_LEFT_CLICK = object
EVT_RICHTEXT_LEFT_DCLICK = object
EVT_RICHTEXT_MIDDLE_CLICK = object
EVT_RICHTEXT_RETURN = object
EVT_RICHTEXT_RIGHT_CLICK = object
EVT_RICHTEXT_SELECTION_CHANGED = object
EVT_RICHTEXT_STYLESHEET_CHANGED = object
EVT_RICHTEXT_STYLESHEET_CHANGING = object
EVT_RICHTEXT_STYLESHEET_REPLACED = object
EVT_RICHTEXT_STYLESHEET_REPLACING = object
EVT_RICHTEXT_STYLE_CHANGED = object
ID_RICHTEXT_PROPERTIES1 = 0
ID_RICHTEXT_PROPERTIES2 = 0
ID_RICHTEXT_PROPERTIES3 = 0
RE_CENTER_CARET = 0
RE_CENTRE_CARET = 0
RE_MULTILINE = 0
RE_READONLY = 0
RICHTEXT_ALL = object
RICHTEXT_ALT_DOWN = 0
RICHTEXT_CACHE_SIZE = 0
RICHTEXT_CHANGE_ATTRIBUTES = object
RICHTEXT_CHANGE_OBJECT = object
RICHTEXT_CHANGE_STYLE = object
RICHTEXT_CTRL_DOWN = 0
RICHTEXT_DELETE = object
RICHTEXT_DRAW_GUIDELINES = 0
RICHTEXT_DRAW_IGNORE_CACHE = 0
RICHTEXT_DRAW_PRINT = 0
RICHTEXT_DRAW_SELECTED = 0
RICHTEXT_EX_NO_GUIDELINES = 0
RICHTEXT_FIXED_HEIGHT = 0
RICHTEXT_FIXED_WIDTH = 0
RICHTEXT_FORMATTED = 0
RICHTEXT_FORMAT_BULLETS = 0
RICHTEXT_FORMAT_FONT = 0
RICHTEXT_FORMAT_INDENTS_SPACING = 0
RICHTEXT_FORMAT_STYLE_EDITOR = 0
RICHTEXT_FORMAT_TABS = 0
RICHTEXT_HANDLER_CONVERT_FACENAMES = 0
RICHTEXT_HANDLER_INCLUDE_STYLESHEET = 0
RICHTEXT_HANDLER_NO_HEADER_FOOTER = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_BASE64 = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_FILES = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_MEMORY = 0
RICHTEXT_HEIGHT_ONLY = 0
RICHTEXT_HITTEST_AFTER = object
RICHTEXT_HITTEST_BEFORE = object
RICHTEXT_HITTEST_HONOUR_ATOMIC = object
RICHTEXT_HITTEST_NONE = object
RICHTEXT_HITTEST_NO_FLOATING_OBJECTS = object
RICHTEXT_HITTEST_NO_NESTED_OBJECTS = object
RICHTEXT_HITTEST_ON = object
RICHTEXT_HITTEST_OUTSIDE = object
RICHTEXT_INSERT = object
RICHTEXT_INSERT_INTERACTIVE = 0
RICHTEXT_INSERT_NONE = 0
RICHTEXT_INSERT_WITH_PREVIOUS_PARAGRAPH_STYLE = 0
RICHTEXT_LAYOUT_SPECIFIED_RECT = 0
RICHTEXT_NONE = object
RICHTEXT_NO_SELECTION = object
RICHTEXT_ORGANISER_APPLY_STYLES = 0
RICHTEXT_ORGANISER_BROWSE = 0
RICHTEXT_ORGANISER_BROWSE_NUMBERING = 0
RICHTEXT_ORGANISER_CREATE_STYLES = 0
RICHTEXT_ORGANISER_DELETE_STYLES = 0
RICHTEXT_ORGANISER_EDIT_STYLES = 0
RICHTEXT_ORGANISER_OK_CANCEL = 0
RICHTEXT_ORGANISER_ORGANISE = 0
RICHTEXT_ORGANISER_RENAME_STYLES = 0
RICHTEXT_ORGANISER_RENUMBER = 0
RICHTEXT_ORGANISER_SHOW_ALL = 0
RICHTEXT_ORGANISER_SHOW_BOX = 0
RICHTEXT_ORGANISER_SHOW_CHARACTER = 0
RICHTEXT_ORGANISER_SHOW_LIST = 0
RICHTEXT_ORGANISER_SHOW_PARAGRAPH = 0
RICHTEXT_PAGE_ALL = object
RICHTEXT_PAGE_CENTRE = object
RICHTEXT_PAGE_EVEN = object
RICHTEXT_PAGE_LEFT = object
RICHTEXT_PAGE_ODD = object
RICHTEXT_PAGE_RIGHT = object
RICHTEXT_SETPROPERTIES_CHARACTERS_ONLY = 0
RICHTEXT_SETPROPERTIES_NONE = 0
RICHTEXT_SETPROPERTIES_PARAGRAPHS_ONLY = 0
RICHTEXT_SETPROPERTIES_REMOVE = 0
RICHTEXT_SETPROPERTIES_RESET = 0
RICHTEXT_SETPROPERTIES_WITH_UNDO = 0
RICHTEXT_SETSTYLE_CHARACTERS_ONLY = 0
RICHTEXT_SETSTYLE_NONE = 0
RICHTEXT_SETSTYLE_OPTIMIZE = 0
RICHTEXT_SETSTYLE_PARAGRAPHS_ONLY = 0
RICHTEXT_SETSTYLE_REMOVE = 0
RICHTEXT_SETSTYLE_RENUMBER = 0
RICHTEXT_SETSTYLE_RESET = 0
RICHTEXT_SETSTYLE_SPECIFY_LEVEL = 0
RICHTEXT_SETSTYLE_WITH_UNDO = 0
RICHTEXT_SHIFT_DOWN = 0
RICHTEXT_TYPE_ANY = object
RICHTEXT_TYPE_HTML = object
RICHTEXT_TYPE_PDF = object
RICHTEXT_TYPE_RTF = object
RICHTEXT_TYPE_TEXT = object
RICHTEXT_TYPE_XML = object
RICHTEXT_UNFORMATTED = 0
RICHTEXT_VARIABLE_HEIGHT = 0
RICHTEXT_VARIABLE_WIDTH = 0
RichTextAction = object
RichTextActionList = object
RichTextActionList_iterator = object
RichTextApplyStyle = dummy_function
RichTextAttr = object
RichTextAttrArray = object
RichTextBitlistsEqPartial = dummy_function
RichTextBox = object
RichTextBuffer = object
RichTextBufferDataObject = object
RichTextCell = object
RichTextCharacterStyleDefinition = object
RichTextCombineBitlists = dummy_function
RichTextCommand = object
RichTextCommandId = object
RichTextCompositeObject = object
RichTextContextMenuPropertiesInfo = object
RichTextCtrl = object
RichTextCtrlSelectionState = object
RichTextCtrlSelectionState_CommonAncestor = object
RichTextCtrlSelectionState_Normal = object
RichTextDecimalToRoman = dummy_function
RichTextDrawingContext = object
RichTextDrawingHandler = object
RichTextDrawingHandlerList = object
RichTextDrawingHandlerList_iterator = object
RichTextEvent = object
RichTextField = object
RichTextFieldType = object
RichTextFieldTypeStandard = object
RichTextFileHandler = object
RichTextFileHandlerList = object
RichTextFileHandlerList_iterator = object
RichTextFileType = object
RichTextFloatCollector = object
RichTextFontTable = object
RichTextFormattingDialog = object
RichTextFormattingDialogFactory = object
RichTextHTMLHandler = object
RichTextHasStyle = dummy_function
RichTextHeaderFooterData = object
RichTextHitTestFlags = object
RichTextImage = object
RichTextImageBlock = object
RichTextLine = object
RichTextLineBreakChar = ''
RichTextLineList = object
RichTextLineList_iterator = object
RichTextListStyleDefinition = object
RichTextModuleInit = dummy_function
RichTextObject = object
RichTextObjectAddress = object
RichTextObjectList = object
RichTextObjectList_ = object
RichTextObjectList__iterator = object
RichTextObjectList_iterator = object
RichTextObjectPtrArray = object
RichTextObjectPtrArrayArray = object
RichTextOddEvenPage = object
RichTextPageLocation = object
RichTextParagraph = object
RichTextParagraphLayoutBox = object
RichTextParagraphStyleDefinition = object
RichTextPlainText = object
RichTextPlainTextHandler = object
RichTextPrinting = object
RichTextPrintout = object
RichTextProperties = object
RichTextRange = object
RichTextRangeArray = object
RichTextRemoveStyle = dummy_function
RichTextRenderer = object
RichTextSelection = object
RichTextSplitParaCharStyles = dummy_function
RichTextStdRenderer = object
RichTextStyleComboCtrl = object
RichTextStyleDefinition = object
RichTextStyleListBox = object
RichTextStyleListCtrl = object
RichTextStyleOrganiserDialog = object
RichTextStyleSheet = object
RichTextTable = object
RichTextTabsEq = dummy_function
RichTextVariantArray = object
RichTextXMLHandler = object
SCRIPT_MUL_FACTOR = 0.0
SymbolPickerDialog = object
TEXT_ATTR_KEEP_FIRST_PARA_STYLE = 0
TEXT_ATTR_UNITS_HUNDREDTHS_POINT = object
TEXT_ATTR_UNITS_MASK = object
TEXT_ATTR_UNITS_PERCENTAGE = object
TEXT_ATTR_UNITS_PIXELS = object
TEXT_ATTR_UNITS_POINTS = object
TEXT_ATTR_UNITS_TENTHS_MM = object
TEXT_ATTR_VALUE_VALID = object
TEXT_ATTR_VALUE_VALID_MASK = object
TEXT_BOX_ATTR_BORDER_COLOUR = object
TEXT_BOX_ATTR_BORDER_DASHED = object
TEXT_BOX_ATTR_BORDER_DOTTED = object
TEXT_BOX_ATTR_BORDER_DOUBLE = object
TEXT_BOX_ATTR_BORDER_GROOVE = object
TEXT_BOX_ATTR_BORDER_INSET = object
TEXT_BOX_ATTR_BORDER_MEDIUM = object
TEXT_BOX_ATTR_BORDER_NONE = object
TEXT_BOX_ATTR_BORDER_OUTSET = object
TEXT_BOX_ATTR_BORDER_RIDGE = object
TEXT_BOX_ATTR_BORDER_SOLID = object
TEXT_BOX_ATTR_BORDER_STYLE = object
TEXT_BOX_ATTR_BORDER_THICK = object
TEXT_BOX_ATTR_BORDER_THIN = object
TEXT_BOX_ATTR_CLEAR = object
TEXT_BOX_ATTR_CLEAR_BOTH = object
TEXT_BOX_ATTR_CLEAR_LEFT = object
TEXT_BOX_ATTR_CLEAR_NONE = object
TEXT_BOX_ATTR_CLEAR_RIGHT = object
TEXT_BOX_ATTR_COLLAPSE_BORDERS = object
TEXT_BOX_ATTR_COLLAPSE_FULL = object
TEXT_BOX_ATTR_COLLAPSE_NONE = object
TEXT_BOX_ATTR_FLOAT = object
TEXT_BOX_ATTR_FLOAT_LEFT = object
TEXT_BOX_ATTR_FLOAT_NONE = object
TEXT_BOX_ATTR_FLOAT_RIGHT = object
TEXT_BOX_ATTR_POSITION_ABSOLUTE = object
TEXT_BOX_ATTR_POSITION_FIXED = object
TEXT_BOX_ATTR_POSITION_MASK = object
TEXT_BOX_ATTR_POSITION_RELATIVE = object
TEXT_BOX_ATTR_POSITION_STATIC = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_BOTTOM = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_CENTRE = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_NONE = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_TOP = object
TextAttrBorder = object
TextAttrBorderFlags = object
TextAttrBorderStyle = object
TextAttrBorderWidth = object
TextAttrBorders = object
TextAttrCollectCommonAttributes = dummy_function
TextAttrDimension = object
TextAttrDimensionConverter = object
TextAttrDimensions = object
TextAttrEq = dummy_function
TextAttrSize = object
TextAttrUnits = object
TextAttrValueFlags = object
TextBoxAttr = object
TextBoxAttrClearStyle = object
TextBoxAttrCollapseMode = object
TextBoxAttrFlags = object
TextBoxAttrFloatStyle = object
TextBoxAttrPosition = object
TextBoxAttrVerticalAlignment = object
_im_RichTextRange = object
wxEVT_RICHTEXT_BUFFER_RESET = 0
wxEVT_RICHTEXT_CHARACTER = 0
wxEVT_RICHTEXT_CONSUMING_CHARACTER = 0
wxEVT_RICHTEXT_CONTENT_DELETED = 0
wxEVT_RICHTEXT_CONTENT_INSERTED = 0
wxEVT_RICHTEXT_DELETE = 0
wxEVT_RICHTEXT_FOCUS_OBJECT_CHANGED = 0
wxEVT_RICHTEXT_LEFT_CLICK = 0
wxEVT_RICHTEXT_LEFT_DCLICK = 0
wxEVT_RICHTEXT_MIDDLE_CLICK = 0
wxEVT_RICHTEXT_PROPERTIES_CHANGED = 0
wxEVT_RICHTEXT_RETURN = 0
wxEVT_RICHTEXT_RIGHT_CLICK = 0
wxEVT_RICHTEXT_SELECTION_CHANGED = 0
wxEVT_RICHTEXT_STYLESHEET_CHANGED = 0
wxEVT_RICHTEXT_STYLESHEET_CHANGING = 0
wxEVT_RICHTEXT_STYLESHEET_REPLACED = 0
wxEVT_RICHTEXT_STYLESHEET_REPLACING = 0
wxEVT_RICHTEXT_STYLE_CHANGED = 0
