# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AC_DEFAULT_STYLE = 0
AC_NO_AUTORESIZE = 0
ANIMATION_TYPE_ANI = object
ANIMATION_TYPE_ANY = object
ANIMATION_TYPE_GIF = object
ANIMATION_TYPE_INVALID = object
AboutBox = dummy_function
AboutDialogInfo = object
Animation = object
AnimationCtrl = object
AnimationCtrlNameStr = bytes()
AnimationType = object
BannerWindow = object
BannerWindowNameStr = bytes()
BitmapComboBox = object
BitmapComboBoxNameStr = bytes()
CAL_BORDER_NONE = object
CAL_BORDER_ROUND = object
CAL_BORDER_SQUARE = object
CAL_HITTEST_DAY = object
CAL_HITTEST_DECMONTH = object
CAL_HITTEST_HEADER = object
CAL_HITTEST_INCMONTH = object
CAL_HITTEST_NOWHERE = object
CAL_HITTEST_SURROUNDING_WEEK = object
CAL_HITTEST_WEEK = object
CAL_MONDAY_FIRST = 0
CAL_NO_MONTH_CHANGE = 0
CAL_NO_YEAR_CHANGE = 0
CAL_SEQUENTIAL_MONTH_SELECTION = 0
CAL_SHOW_HOLIDAYS = 0
CAL_SHOW_SURROUNDING_WEEKS = 0
CAL_SHOW_WEEK_NUMBERS = 0
CAL_SUNDAY_FIRST = 0
CalculateLayoutEvent = object
CalendarCtrl = object
CalendarDateAttr = object
CalendarDateBorder = object
CalendarEvent = object
CalendarHitTestResult = object
CalendarNameStr = bytes()
CommandLinkButton = object
CreateFileTipProvider = dummy_function
DP_ALLOWNONE = 0
DP_DEFAULT = 0
DP_DROPDOWN = 0
DP_SHOWCENTURY = 0
DP_SPIN = 0
DateEvent = object
DatePickerCtrl = object
EL_ALLOW_DELETE = 0
EL_ALLOW_EDIT = 0
EL_ALLOW_NEW = 0
EL_DEFAULT_STYLE = 0
EL_NO_REORDER = 0
EVT_CALCULATE_LAYOUT = object
EVT_CALENDAR = object
EVT_CALENDAR_DAY = object
EVT_CALENDAR_MONTH = object
EVT_CALENDAR_PAGE_CHANGED = object
EVT_CALENDAR_SEL_CHANGED = object
EVT_CALENDAR_WEEKDAY_CLICKED = object
EVT_CALENDAR_WEEK_CLICKED = object
EVT_CALENDAR_YEAR = object
EVT_DATE_CHANGED = object
EVT_HYPERLINK = object
EVT_QUERY_LAYOUT_INFO = object
EVT_SASH_DRAGGED = object
EVT_SASH_DRAGGED_RANGE = object
EVT_TASKBAR_BALLOON_CLICK = object
EVT_TASKBAR_BALLOON_TIMEOUT = object
EVT_TASKBAR_CLICK = object
EVT_TASKBAR_LEFT_DCLICK = object
EVT_TASKBAR_LEFT_DOWN = object
EVT_TASKBAR_LEFT_UP = object
EVT_TASKBAR_MOVE = object
EVT_TASKBAR_RIGHT_DCLICK = object
EVT_TASKBAR_RIGHT_DOWN = object
EVT_TASKBAR_RIGHT_UP = object
EVT_TIME_CHANGED = object
EVT_WIZARD_BEFORE_PAGE_CHANGED = object
EVT_WIZARD_CANCEL = object
EVT_WIZARD_FINISHED = object
EVT_WIZARD_HELP = object
EVT_WIZARD_PAGE_CHANGED = object
EVT_WIZARD_PAGE_CHANGING = object
EVT_WIZARD_PAGE_SHOWN = object
EditableListBox = object
EditableListBoxNameStr = bytes()
ExtHelpController = object
GenericAboutBox = dummy_function
GenericCalendarCtrl = object
GenericDatePickerCtrl = object
HL_ALIGN_CENTRE = 0
HL_ALIGN_LEFT = 0
HL_ALIGN_RIGHT = 0
HL_CONTEXTMENU = 0
HL_DEFAULT_STYLE = 0
HyperlinkCtrl = object
HyperlinkCtrlNameStr = bytes()
HyperlinkEvent = object
Joystick = object
LAYOUT_BOTTOM = object
LAYOUT_HORIZONTAL = object
LAYOUT_LEFT = object
LAYOUT_NONE = object
LAYOUT_RIGHT = object
LAYOUT_TOP = object
LAYOUT_VERTICAL = object
LayoutAlgorithm = object
LayoutAlignment = object
LayoutOrientation = object
NotificationMessage = object
NullAnimation = object
ODCB_DCLICK_CYCLES = 0
ODCB_PAINTING_CONTROL = object
ODCB_PAINTING_SELECTED = object
ODCB_STD_CONTROL_PAINT = 0
OwnerDrawnComboBox = object
OwnerDrawnComboBoxPaintingFlags = object
PROPSHEET_BUTTONTOOLBOOK = object
PROPSHEET_CHOICEBOOK = object
PROPSHEET_DEFAULT = object
PROPSHEET_LISTBOOK = object
PROPSHEET_NOTEBOOK = object
PROPSHEET_SHRINKTOFIT = object
PROPSHEET_TOOLBOOK = object
PROPSHEET_TREEBOOK = object
PropertySheetDialog = object
PropertySheetDialogFlags = object
PseudoDC = object
PyWizardPage = object
QueryLayoutInfoEvent = object
RichToolTip = object
SASH_BOTTOM = object
SASH_LEFT = object
SASH_NONE = object
SASH_RIGHT = object
SASH_STATUS_OK = object
SASH_STATUS_OUT_OF_RANGE = object
SASH_TOP = object
SOUND_ASYNC = 0
SOUND_LOOP = 0
SOUND_SYNC = 0
SPLASH_CENTER_ON_PARENT = 0
SPLASH_CENTER_ON_SCREEN = 0
SPLASH_CENTRE_ON_PARENT = 0
SPLASH_CENTRE_ON_SCREEN = 0
SPLASH_NO_CENTER = 0
SPLASH_NO_CENTRE = 0
SPLASH_NO_TIMEOUT = 0
SPLASH_TIMEOUT = 0
SW_3D = 0
SW_3DBORDER = 0
SW_3DSASH = 0
SW_BORDER = 0
SW_NOBORDER = 0
SashDragStatus = object
SashEdgePosition = object
SashEvent = object
SashLayoutWindow = object
SashWindow = object
ShowTip = dummy_function
Sound = object
SplashScreen = object
TBI_CUSTOM_STATUSITEM = object
TBI_DEFAULT_TYPE = object
TBI_DOCK = object
TP_DEFAULT = 0
TaskBarIcon = object
TaskBarIconEvent = object
TaskBarIconType = object
TimePickerCtrl = object
TipKind = object
TipKind_Auto = object
TipKind_Bottom = object
TipKind_BottomLeft = object
TipKind_BottomRight = object
TipKind_None = object
TipKind_Top = object
TipKind_TopLeft = object
TipKind_TopRight = object
TipProvider = object
USE_JOYSTICK = 0
WIZARD_EX_HELPBUTTON = 0
WIZARD_HALIGN_CENTRE = 0
WIZARD_HALIGN_LEFT = 0
WIZARD_HALIGN_RIGHT = 0
WIZARD_TILE = 0
WIZARD_VALIGN_BOTTOM = 0
WIZARD_VALIGN_CENTRE = 0
WIZARD_VALIGN_TOP = 0
Wizard = object
WizardEvent = object
WizardPage = object
WizardPageSimple = object
wxEVT_CALCULATE_LAYOUT = 0
wxEVT_CALENDAR_DAY_CHANGED = 0
wxEVT_CALENDAR_DOUBLECLICKED = 0
wxEVT_CALENDAR_MONTH_CHANGED = 0
wxEVT_CALENDAR_PAGE_CHANGED = 0
wxEVT_CALENDAR_SEL_CHANGED = 0
wxEVT_CALENDAR_WEEKDAY_CLICKED = 0
wxEVT_CALENDAR_WEEK_CLICKED = 0
wxEVT_CALENDAR_YEAR_CHANGED = 0
wxEVT_COMMAND_HYPERLINK = 0
wxEVT_DATE_CHANGED = 0
wxEVT_HYPERLINK = 0
wxEVT_QUERY_LAYOUT_INFO = 0
wxEVT_SASH_DRAGGED = 0
wxEVT_TASKBAR_BALLOON_CLICK = 0
wxEVT_TASKBAR_BALLOON_TIMEOUT = 0
wxEVT_TASKBAR_CLICK = 0
wxEVT_TASKBAR_LEFT_DCLICK = 0
wxEVT_TASKBAR_LEFT_DOWN = 0
wxEVT_TASKBAR_LEFT_UP = 0
wxEVT_TASKBAR_MOVE = 0
wxEVT_TASKBAR_RIGHT_DCLICK = 0
wxEVT_TASKBAR_RIGHT_DOWN = 0
wxEVT_TASKBAR_RIGHT_UP = 0
wxEVT_TIME_CHANGED = 0
wxEVT_WIZARD_BEFORE_PAGE_CHANGED = 0
wxEVT_WIZARD_CANCEL = 0
wxEVT_WIZARD_FINISHED = 0
wxEVT_WIZARD_HELP = 0
wxEVT_WIZARD_PAGE_CHANGED = 0
wxEVT_WIZARD_PAGE_CHANGING = 0
wxEVT_WIZARD_PAGE_SHOWN = 0
