# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PARAMTAG = ''
WXPTAG = ''
_Context = object
_my_import = dummy_function
_param2dict = dummy_function
wxpTagHandler = object
